diff --git a/core/includes/menu.inc b/core/includes/menu.inc
index c7fcd92..8eeee36 100644
--- a/core/includes/menu.inc
+++ b/core/includes/menu.inc
@@ -1755,6 +1755,7 @@ function menu_list_system_menus() {
     'admin' => 'Administration',
     'account' => 'User account menu',
     'main' => 'Main navigation',
+    'footer' => 'Footer menu',
   );
 }
 
diff --git a/core/modules/contact/contact.module b/core/modules/contact/contact.module
index 1087308..4bdb4c0 100644
--- a/core/modules/contact/contact.module
+++ b/core/modules/contact/contact.module
@@ -90,7 +90,7 @@ function contact_menu() {
     'page callback' => 'drupal_get_form',
     'page arguments' => array('contact_site_form'),
     'access arguments' => array('access site-wide contact form'),
-    'menu_name' => 'main',
+    'menu_name' => 'footer',
     'type' => MENU_SUGGESTED_ITEM,
     'file' => 'contact.pages.inc',
   );
diff --git a/core/modules/menu/menu.install b/core/modules/menu/menu.install
index 20277a7..e84b0c4 100644
--- a/core/modules/menu/menu.install
+++ b/core/modules/menu/menu.install
@@ -51,6 +51,7 @@ function menu_install() {
     'account' => $t('Links related to the user account.'),
     'admin' => $t('Contains links to administrative tasks.'),
     'main' => $t('Use this for linking to the main site sections.'),
+    'footer' => $t('Use this for linking to site information.'),
   );
   foreach ($system_menus as $menu_name => $title) {
     $menu = array(
@@ -101,3 +102,15 @@ function menu_update_8001() {
   }
 }
 
+/**
+ * Adds the footer menu to custom menus.
+ */
+function menu_update_8002() {
+  db_insert('menu_custom')
+    ->fields(array(
+      'menu_name' => 'footer',
+      'title' => 'Footer menu',
+      'description' => 'Use this for linking to site information.',
+    ));
+}
+
diff --git a/core/profiles/standard/standard.info b/core/profiles/standard/standard.info
index 8b8a33b..44739cc 100644
--- a/core/profiles/standard/standard.info
+++ b/core/profiles/standard/standard.info
@@ -7,6 +7,7 @@ dependencies[] = block
 dependencies[] = color
 dependencies[] = comment
 dependencies[] = contextual
+dependencies[] = contact
 dependencies[] = help
 dependencies[] = image
 dependencies[] = menu
diff --git a/core/profiles/standard/standard.install b/core/profiles/standard/standard.install
index b4dc761..c311e91 100644
--- a/core/profiles/standard/standard.install
+++ b/core/profiles/standard/standard.install
@@ -120,6 +120,16 @@ function standard_install() {
     ),
     array(
       'module' => 'system',
+      'delta' => 'menu-footer',
+      'theme' => $default_theme,
+      'status' => 1,
+      'weight' => 0,
+      'region' => 'footer',
+      'pages' => '',
+      'cache' => -1,
+    ),
+    array(
+      'module' => 'system',
       'delta' => 'powered-by',
       'theme' => $default_theme,
       'status' => 1,
diff --git a/core/themes/bartik/template.php b/core/themes/bartik/template.php
index 5373c92..9a6c8a9 100644
--- a/core/themes/bartik/template.php
+++ b/core/themes/bartik/template.php
@@ -114,8 +114,8 @@ function bartik_process_maintenance_page(&$variables) {
  * Implements hook_preprocess_HOOK() for block.tpl.php.
  */
 function bartik_preprocess_block(&$variables) {
-  // In the header region visually hide block titles.
-  if ($variables['block']->region == 'header') {
+  // In the header and footer regions visually hide block titles.
+  if ($variables['block']->region == 'header' || $variables['block']->region == 'footer') {
     $variables['title_attributes']['class'][] = 'element-invisible';
   }
 }
